@@ -4,10 +4,11 @@
 #' respects the environment variable \code{OMP_NUM_THREADS}.
 #' 
 #' @return
-#' An integer; the number of threads.
+#' The number of cores + hyperthreads on the system (an integer).
 #' 
+#' @useDynLib meanr R_meanr_nthreads
 #' @export
-meanr.nthreads <- function()
+meanr.nthreads = function()
 {
   .Call(R_meanr_nthreads)
 }
